function [depl,vel,accl] = Dynamic_Solution_Newmark(M,K,C,active_Dof)

global t dt load1 load2 load3
global GDof

% Average
gaama = 1/2;
beta = 1/4;

% Time step
nt = length(t);

% Constants used in Newmark's integration
a1 = gaama/(beta*dt);   
a2 = 1/(beta*dt^2);
a3 = 1/(beta*dt);       
a4 = gaama/beta;
a5 = 1/(2*beta);        
a6 = (gaama/(2*beta)-1)*dt;

depl = zeros(GDof,nt);
vel = zeros(GDof,nt);
accl = zeros(GDof,nt);

force = sparse(GDof,1);
force1 = sparse(GDof,1);
force2 = sparse(GDof,1);

% Initial Conditions
depl(:,1) = zeros;
vel(:,1) = zeros;
accl(:,1) = zeros;

% Acceleration t=0
force(end-5) = load1(1);
force(end-4) = load2(1);
force(end-3) = load3(1); 
accl(active_Dof,1) = M(active_Dof,active_Dof)\(force(active_Dof)-...
    C(active_Dof,active_Dof)*vel(active_Dof,1)-K(active_Dof,active_Dof)...
    *depl(active_Dof,1)) ;

Kcap = K(active_Dof,active_Dof)+a1*C(active_Dof,active_Dof)+...
    a2*M(active_Dof,active_Dof);
L = chol(Kcap,'lower');

a = a3*M(active_Dof,active_Dof)+a4*C(active_Dof,active_Dof);
b = a5*M(active_Dof,active_Dof)+a6*C(active_Dof,active_Dof);

% Time step starts
for i = 1:nt-1
    
    force1(end-5) = load1(i);
    force1(end-4) = load2(i);
    force1(end-3) = load3(i);
    
    force2(end-5) = load1(i+1);
    force2(end-4) = load2(i+1);
    force2(end-3) = load3(i+1);

    delP = (force2(active_Dof)-force1(active_Dof))+a*vel(active_Dof,i)+...
        b*accl(active_Dof,i);
    temp = L\delP;
    delu = L'\temp ;
    delv = a1*delu-a4*vel(active_Dof,i)-a6*accl(active_Dof,i);
    dela = a2*delu-a3*vel(active_Dof,i)-a5*accl(active_Dof,i);
    depl(active_Dof,i+1) = depl(active_Dof,i)+delu;
    vel(active_Dof,i+1) = vel(active_Dof,i)+delv;
    accl(active_Dof,i+1) = accl(active_Dof,i)+dela;
   
end