%% 3D Beam Elements FEM

function [depl,vel,accl,My,Mz,f] = FEM_Beam(numberElements,...
    nodeCoordinates,elementNodes,active_Dof,PDFArea,Di,PDSoil,PDAeroDy)
%% Stiffness and Mass Matrix

global Damping WindSpeed ProbAnalysis 
global Ls
global numberElementsFoundation
global NElement GDofPN GDof GDofPE
global t

EDof=zeros(elementNodes(end,1),NElement*GDofPN);

% Topology Matrix
for i=1:numberElements
    for j=1:GDofPE
        EDof(i,j)=(i-1)*6+j;
    end
end

K = sparse(GDof,GDof);
M = sparse(GDof,GDof);
C = sparse(GDof,GDof);
Iy = zeros(numberElements,1);
Iz = zeros(numberElements,1);

for i=1:numberElements
    
% Ki element stiffness matrix
% Mi element mass matrix
% Ci element damping matrix
% Kis element stiffness matrix for soil
% Mi element mass matrix for the rotor
    
    switch ProbAnalysis
        
        case {'Area','Combined'}
    
    [Iyi,Izi,Ji] = Beam_Geometry_PDFArea (PDFArea(i),Di(i));
    Lel = sqrt((nodeCoordinates(i+1,1)-nodeCoordinates(i,1))^2);
    
    Iy(i) = Iyi;
    Iz(i) = Izi;

    [Mi,Ki,Ci,Kis,Mirot] = Stiffness_Mass_Damping_Matrix (PDFArea(i),...
        Iyi, Izi, Ji, Lel, PDAeroDy(i));
    
        case {'Soil','Aerodynamic Damping'}
            
    [A,Iyi,Izi,Ji] = Beam_Geometry (elementNodes(i,1), numberElements);
    Lel = sqrt((nodeCoordinates(i+1,1)-nodeCoordinates(i,1))^2);
    
    Iy(i) = Iyi;
    Iz(i) = Izi;

    [Mi,Ki,Ci,Kis,Mirot] = Stiffness_Mass_Damping_Matrix (A, Iyi, Izi,...
        Ji, Lel, PDAeroDy(i));
    
    end
            
% Global Structure stiffness, mass and damping (referred to O in general 
% axis)
    K(EDof(i,:), EDof(i,:))=K(EDof(i,:), EDof(i,:))+Ki;
    M(EDof(i,:), EDof(i,:))=M(EDof(i,:), EDof(i,:))+Mi;
    C(EDof(i,:), EDof(i,:))=C(EDof(i,:), EDof(i,:))+Ci;
end

% Add soil stiffness
for i=1:numberElementsFoundation/2
    Dsoil = 6;
    xsoil = linspace(Ls,0,numberElementsFoundation+1)';
    Ksoil = Dsoil*xsoil(i*2)*Stiffness_Soil_Funct(Friction_Angle_Funct...
        (xsoil(i*2),PDSoil));
            
    K(EDof(i*2,:), EDof(i*2,:))=K(EDof(i*2,:), EDof(i*2,:))+Ksoil*Kis;
    
end

% Add rotor mass
for i=numberElements
    M(EDof(i,:), EDof(i,:))=M(EDof(i,:), EDof(i,:))+Mirot;
end

% Add aerodynamic damping D2
switch Damping
    
case 'DTop'
    
switch ProbAnalysis
    
    case {'Area','Soil'}

        switch WindSpeed
            case '8 m/s'
                aerodynamicDamping = 0.0349;
            case '14 m/s'
                aerodynamicDamping = 0.0573;
            case '18 m/s'
                aerodynamicDamping = 0.0641;
        end

        for i=numberElements
            C(EDof(i,:), EDof(i,:))=C(EDof(i,:), EDof(i,:))+Ki*...
                aerodynamicDamping;
        end
        
    case {'Aerodynamic Damping','Combined'}
        
        for i=numberElements
            C(EDof(i,:), EDof(i,:))=C(EDof(i,:), EDof(i,:))+Ki*PDAeroDy(1);
        end

end

end

%% Eigenfrequencies

Keig=full(K);
Meig=full(M);
Kref=Keig(7:end,7:end);
Mref=Meig(7:end,7:end);
[V,W]=eig(Kref,Mref);
wn=sort(diag(sqrt(W)));
f=wn(1:25)/2/pi;

%% System solving - Dynamic problem

[depl,vel,accl] = Dynamic_Solution_Newmark(M,K,C,active_Dof);

%% Bending moment

My=zeros(numberElements,length(t));
Mz=zeros(numberElements,length(t));

for i=1:length(t)
    [Myi, Mzi] = Bending_Moment (numberElements,nodeCoordinates,...
        depl(:,i),EDof,Iy,Iz);
    
    My(:,i) = Myi;
    Mz(:,i) = Mzi;
end

end