%% PROBABILISTIC ANALYSIS

clear all; close all; clc
disp(' PROBABILISTIC ANALYSIS ')

%% Input Data:

global Damping WindSpeed ProbAnalysis numberSamples

% Damping: DStr (Structure), DTop (Top support structure)
Damping = 'DTop';
fprintf('\n- Damping: %s.\n',Damping)

% Wind Speeds: 8 m/s, 14 m/s, 18 m/s
WindSpeed = '18 m/s';                
fprintf('- Wind Speed: %s.\n',WindSpeed)

% Prob. Analysis: Area, Soil, Aerodynamic Damping, Combined
ProbAnalysis = 'Combined';
fprintf('- Variable Analysis: %s.\n',ProbAnalysis)

% Study case: Correlated case, Non-Correlated case
Case = 'Correlated';         
fprintf('- Case: %s.\n',Case)

    % Study case: Correlated case, Non-Correlated case
    CombinedAreaCase = 'Non-Correlated';         
    fprintf('- Combined Area Case: %s.\n',CombinedAreaCase)

    % Study case: Correlated case, Non-Correlated case
    CombinedSoilCase = 'Non-Correlated';         
    fprintf('- Combined Soil Case: %s.\n\n',CombinedSoilCase)

% Number of samples
numberSamples = 200;

tic;                          % Start clock
ttim = 0;                     % Initialize time counter

% Units: m; N; kg; Pa
global E G poisson rho Ls

E = 210e9;                    % E: modulus of elasticity
G = 80.8e9;                   % Shear modulus (G = E/2/(1+poisson)
poisson = 0.30;               % poisson: Poisson's ratio
rho = 8500;                   % rho: specific weight of steel

Ltp = 77.6;                   % Ltp: Tower-Top Height Above Ltb
Ltb = 10;                     % Ltb: Tower-Base Height Above MSL
Lw = 20;                      % Lw: Water Depth (From MSL)
Ls = 40;                      % Ls: length of the foundation
L = Ltp+Ltb+Lw+Ls;            % L: length total

%% Generation of coordinates and connectivities

global numberElementsTowerTop numberElementsTowerBase ...
    numberElementsFoundation

numberElementsTowerTop=11;
numberElementsTowerBase=3;
numberElementsFoundation=40;
numberElements=numberElementsTowerTop+numberElementsTowerBase+...
    numberElementsFoundation;

nodeCoordinatesBeam=[linspace(0,Ls,numberElementsFoundation+1)';Ls+...
    (linspace((Ltb+Lw)/numberElementsTowerBase,(Ltb+Lw),...
    numberElementsTowerBase))';
    Ls+Ltb+Lw+(linspace(Ltp/numberElementsTowerTop,Ltp,...
    numberElementsTowerTop))'];
nodeCoordinates=[nodeCoordinatesBeam zeros(numberElements+1,1) ...
    zeros(numberElements+1,1)];
numberNodes=size(nodeCoordinates,1);

elementNodes=zeros(numberElements,2);
bendingCoord=zeros(numberElements,1);

for i=1:numberElements;
    elementNodes(i,1)=i;
    elementNodes(i,2)=i+1;
    
    bendingCoord(i) =(nodeCoordinates(elementNodes(i,1)) + ...
        nodeCoordinates(elementNodes(i,2)))/2;
    
end

global NElement GDofPN GDof GDofPE
  
NElement=2;                 % NElement: number of nodes per element
GDofPN=6;                   % GDofPN: degrees of freedom per node
GDof=GDofPN*numberNodes;    % GDof: global number of degrees of freedom
GDofPE=GDofPN*NElement;     % GDofPE: degrees of freedom per element

ttim = Timing('Time needed to set initial values',ttim); %Reporting time

%% Boundary conditions

% prescribed DOF
prescribed_Dof=(1:1)';

% active DOF
active_Dof=setdiff((1:GDof)',prescribed_Dof);

%% Loads

addpath('Loads');

switch WindSpeed
    
    case '8 m/s'
        data1 = dlmread('FxWs8.txt');
        data2 = dlmread('FyWs8.txt');
        data3 = dlmread('FzWs8.txt');

    case '14 m/s'
        data1 = dlmread('FxWs14.txt');
        data2 = dlmread('FyWs14.txt');
        data3 = dlmread('FzWs14.txt');

    case '18 m/s'
        data1 = dlmread('FxWs18.txt');
        data2 = dlmread('FyWs18.txt');
        data3 = dlmread('FzWs18.txt');

end

global t dt load1 load2 load3

t=data1(:,1);
dt=data1(2,1)-data1(1,1);
load1=data3(:,2);           % Load in the x-axis
load2=data1(:,2);           % Load in the y-axis
load3=data2(:,2);           % Load in the z-axis

ttim = Timing('Time needed to read the input file',ttim); %Reporting time

%% Probability distribution

% Area analysis
PDArea = zeros(numberElements,numberSamples);
Di = zeros(numberElements,1);
Ai = zeros(numberElements,1);

% Soil analysis
phi = [38;35;38;38;42;42.5];
PDSoil = zeros(length(phi),numberSamples);

% Aerodynamic analysis
PDAeroDy = zeros(numberElements,numberSamples);

switch Damping
    
case 'DStr'

switch ProbAnalysis
    
% PDF Area
    
case 'Area'

    switch Case

        case 'Non-Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    mean1=A;
                    sd1=0.05;
                    mu = log((mean1^2)/sqrt(sd1+mean1^2));
                    sigma = sqrt(log(sd1/(mean1^2)+1));
                    X = lognrnd(mu,sigma,1,numberSamples);

                    PDArea(i,:) = X;
                    Di(i)=Dint;

                end
     
        case 'Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    Ai(i)=A;
                    Di(i)=Dint;

                end

                mean1=Ai(1);
                sd1=0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDArea(1,:) = X;

                for i=2:numberElements

                        mean2 = Ai(i);
                        sd2 = 0.05;
                        X=mean2*(((PDArea(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                    PDArea(i,:) = X;

                end

    end
    
% PDF Soil
   
case 'Soil'

    switch Case

        case 'Non-Correlated'

            for i=1:length(phi)

                mean1 = phi(i);
                sd1 = phi(i)*0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDSoil(i,:) = X;

             end
   
        case 'Correlated'

            mean1=phi(1);
            sd1=mean1*0.05;
            mu = log((mean1^2)/sqrt(sd1+mean1^2));
            sigma = sqrt(log(sd1/(mean1^2)+1));
            X = lognrnd(mu,sigma,1,numberSamples);

            PDSoil(1,:) = X;

            for i=2:length(phi)

                mean2=phi(i);
                sd2=mean2*0.05;
                X = mean2*(((PDSoil(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                PDSoil(i,:) = X;

            end
                                
    end
    
% PDF Aerodynamic Damping
    
case 'Aerodynamic Damping'
    
    switch WindSpeed
        
        case '8 m/s'
                    
                mean1 = 0.0349;
                sd1 = 0.0025;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

                for i=2:numberElements

                        mean2=mean1;
                        sd2 = 0.0025;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;

                end

            case '14 m/s'

                mean1 = 0.0573;
                sd1 = 0.0015;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

                for i=2:numberElements

                        mean2=mean1;
                        sd2 = 0.0015;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;

                end

            case '18 m/s'

                mean1 = 0.0641;
                sd1 = 0.0031;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;  

                for i=2:numberElements

                        mean2=mean1;
                        sd2=0.0031;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;
                end
                    
    end
    
case 'Combined'
    
% Area
   
    switch CombinedAreaCase

        case 'Non-Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    mean1=A;
                    sd1=0.05;
                    mu = log((mean1^2)/sqrt(sd1+mean1^2));
                    sigma = sqrt(log(sd1/(mean1^2)+1));
                    X = lognrnd(mu,sigma,1,numberSamples);

                    PDArea(i,:) = X;
                    Di(i)=Dint;

                end
       
        case 'Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    Ai(i)=A;
                    Di(i)=Dint;

                end

                mean1=Ai(1);
                sd1=0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDArea(1,:) = X;

                for i=2:numberElements

                        mean2=Ai(i);
                        sd2=0.05;
                        X=mean2*(((PDArea(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                    PDArea(i,:) = X;

                end

    end
    
% PDF Soil

    switch CombinedSoilCase

        case 'Non-Correlated'

            for i=1:length(phi)

                mean1 = phi(i);
                sd1 = phi(i)*0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDSoil(i,:) = X;

             end
   
        case 'Correlated'

            mean1=phi(1);
            sd1=mean1*0.05;
            mu = log((mean1^2)/sqrt(sd1+mean1^2));
            sigma = sqrt(log(sd1/(mean1^2)+1));
            X = lognrnd(mu,sigma,1,numberSamples);

            PDSoil(1,:) = X;

            for i=2:length(phi)

                mean2=phi(i);
                sd2=mean2*0.05;
                X = mean2*(((PDSoil(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                PDSoil(i,:) = X;

            end
                                
    end
    
% PDF Aerodynamic Damping
    
    switch WindSpeed
        
        case '8 m/s'
                    
                mean1 = 0.0349;
                sd1 = 0.0025;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

                for i=2:numberElements

                        mean2=mean1;
                        sd2 = 0.0025;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;

                end

            case '14 m/s'

                mean1 = 0.0573;
                sd1 = 0.0015;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

                for i=2:numberElements

                        mean2=mean1;
                        sd2 = 0.0015;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;

                end

            case '18 m/s'

                mean1 = 0.0641;
                sd1 = 0.0031;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;  

                for i=2:numberElements

                        mean2=mean1;
                        sd2 = 0.0031;
                        X=mean2*(((PDAeroDy(1,:)-mean1)/mean1)*(sd2/sd1)...
                            +1);

                    PDAeroDy(i,:) = X;
                end
                    
    end
    
end

case 'DTop'
      
switch ProbAnalysis
    
% PDF Area
    
case 'Area'

    switch Case

        case 'Non-Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    mean1=A;
                    sd1=0.05;
                    mu = log((mean1^2)/sqrt(sd1+mean1^2));
                    sigma = sqrt(log(sd1/(mean1^2)+1));
                    X = lognrnd(mu,sigma,1,numberSamples);

                    PDArea(i,:) = X;
                    Di(i)=Dint;

                end
         
        case 'Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    Ai(i)=A;
                    Di(i)=Dint;

                end

                mean1=Ai(1);
                sd1=0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDArea(1,:) = X;

                for i=2:numberElements

                        mean2=Ai(i);
                        sd2=0.05;
                        X=mean2*(((PDArea(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                    PDArea(i,:) = X;

                end

    end
    
% PDF Soil
   
case 'Soil'

    switch Case

        case 'Non-Correlated'

            for i=1:length(phi)

                mean1 = phi(i);
                sd1 = phi(i)*0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDSoil(i,:) = X;

             end
   
        case 'Correlated'

            mean1=phi(1);
            sd1=mean1*0.05;
            mu = log((mean1^2)/sqrt(sd1+mean1^2));
            sigma = sqrt(log(sd1/(mean1^2)+1));
            X = lognrnd(mu,sigma,1,numberSamples);

            PDSoil(1,:) = X;

            for i=2:length(phi)

                mean2=phi(i);
                sd2=mean2*0.05;
                X = mean2*(((PDSoil(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                PDSoil(i,:) = X;

            end
                                
    end
    
% PDF Aerodynamic Damping
    
case 'Aerodynamic Damping'
    
    switch WindSpeed
        
        case '8 m/s'
                    
                mean1 = 0.0349;
                sd1 = 0.0025;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

            case '14 m/s'

                mean1 = 0.0573;
                sd1 = 0.0015;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

            case '18 m/s'

                mean1 = 0.0641;
                sd1 = 0.0031;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;
                    
    end
    
case 'Combined'
    
% PDF Area
   
    switch CombinedAreaCase

        case 'Non-Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    mean1=A;
                    sd1=0.05;
                    mu = log((mean1^2)/sqrt(sd1+mean1^2));
                    sigma = sqrt(log(sd1/(mean1^2)+1));
                    X = lognrnd(mu,sigma,1,numberSamples);

                    PDArea(i,:) = X;
                    Di(i)=Dint;

                end
                    
        case 'Correlated'
                for i=1:numberElements

                    [A,~,~,~,Dint] = Beam_Geometry (elementNodes(i,1),...
                        numberElements);

                    Ai(i)=A;
                    Di(i)=Dint;

                end

                mean1=Ai(1);
                sd1=0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDArea(1,:) = X;

                for i=2:numberElements

                        mean2=Ai(i);
                        sd2=0.05;
                        X=mean2*(((PDArea(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                    PDArea(i,:) = X;

                end

    end
    
% PDF Soil

    switch CombinedSoilCase

        case 'Non-Correlated'

            for i=1:length(phi)

                mean1 = phi(i);
                sd1 = phi(i)*0.05;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDSoil(i,:) = X;

             end
   
        case 'Correlated'

            mean1=phi(1);
            sd1=mean1*0.05;
            mu = log((mean1^2)/sqrt(sd1+mean1^2));
            sigma = sqrt(log(sd1/(mean1^2)+1));
            X = lognrnd(mu,sigma,1,numberSamples);

            PDSoil(1,:) = X;

            for i=2:length(phi)

                mean2=phi(i);
                sd2=mean2*0.05;
                X = mean2*(((PDSoil(1,:)-mean1)/mean1)*(sd2/sd1)+1);

                PDSoil(i,:) = X;

            end
                                
    end
    
% PDF Aerodynamic Damping
    
    switch WindSpeed
        
        case '8 m/s'
                    
                mean1 = 0.0349;
                sd1 = 0.0025;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

            case '14 m/s'

                mean1 = 0.0573;
                sd1 = 0.0015;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;

            case '18 m/s'

                mean1 = 0.0641;
                sd1 = 0.0031;
                mu = log((mean1^2)/sqrt(sd1+mean1^2));
                sigma = sqrt(log(sd1/(mean1^2)+1));
                X = lognrnd(mu,sigma,1,numberSamples);

                PDAeroDy(1,:) = X;
                    
    end
    
end
               
end

%% Finite element analysis

DeleteTime = 120/dt+1;
tf = t(DeleteTime:end);

Freq=zeros(25,numberSamples);

DisplTopXT = zeros(numberSamples,length(tf));
DisplTopYT = zeros(numberSamples,length(tf));
DisplTopZT = zeros(numberSamples,length(tf));

BMMudlineYT = zeros(numberSamples,length(tf));
BMMudlineZT = zeros(numberSamples,length(tf));

dmg_DisplTopXT = zeros(numberSamples,1);
dmg_DisplTopYT = zeros(numberSamples,1);
dmg_DisplTopZT = zeros(numberSamples,1);

dmg_BMMudlineYT = zeros(numberSamples,1);
dmg_BMMudlineZT = zeros(numberSamples,1);

for i=1:numberSamples

    [depli,veli,accli,Myi,Mzi,f] = FEM_Beam (numberElements,...
        nodeCoordinates,elementNodes,active_Dof,PDArea(:,i),Di,...
        PDSoil(:,i),PDAeroDy(:,i));
    
    Freq(:,i)=f;
    
    [DisplTopX,DisplTopY,DisplTopZ,BMMudlineY,BMMudlineZ] = Save_Data ...
        (depli,Myi,Mzi,DeleteTime);
    
    DisplTopXT(i,:) = DisplTopX;
    DisplTopYT(i,:) = DisplTopY;
    DisplTopZT(i,:) = DisplTopZ;
 
    BMMudlineYT(i,:) = BMMudlineY;
    BMMudlineZT(i,:) = BMMudlineZ;
    
    [RF_DisplTopX_dmg,RF_DisplTopY_dmg,RF_DisplTopZ_dmg,...
        RF_BMMudlineY_dmg,RF_BMMudlineZ_dmg] = RF_Results_Damage ...
        (DisplTopX,DisplTopY,DisplTopZ,BMMudlineY,BMMudlineZ);

    dmg_DisplTopXT(i)=RF_DisplTopX_dmg;
    dmg_DisplTopYT(i)=RF_DisplTopY_dmg;
    dmg_DisplTopZT(i)=RF_DisplTopZ_dmg;
    
    dmg_BMMudlineYT(i)=RF_BMMudlineY_dmg;
    dmg_BMMudlineZT(i)=RF_BMMudlineZ_dmg;

ttim = Timing('Time needed to solve the FE model',ttim); %Reporting time

end

%% Rainflow counting computation

[RF_DisplTopX,RF_DisplTopY,RF_DisplTopZ,RF_BMMudlineY,RF_BMMudlineZ] ...
    = RF_Results(DisplTopXT,DisplTopYT,DisplTopZT,BMMudlineYT,BMMudlineZT);

%% Graphs

NSamples = 1;

Graphs (NSamples,DisplTopX,DisplTopY,DisplTopZ,BMMudlineY,...
    BMMudlineZ,tf);

fprintf(1,'\nTotal running time %12.6f \n\n',ttim); %Reporting final time
