function [M,K,C,Ks,Mrot] = Stiffness_Mass_Damping_Matrix (A, Iy, Iz, J,...
    L, PDAeroDy)

global Damping WindSpeed ProbAnalysis 
global E G poisson rho

kc = 10*(1+poisson)/(12+11*poisson);
Ay = A/kc;
Az = A/kc;

% Shear deformation effects
phiy = 1*12*E*Iz/(G*Az*L^2);
phiz = 1*12*E*Iy/(G*Ay*L^2);

az =  12*E*Iz/(L^3*(1+phiy));
ay =  12*E*Iy/(L^3*(1+phiz));
bz = -12*E*Iz/(L^3*(1+phiy));
by = -12*E*Iy/(L^3*(1+phiz));
cz =   6*E*Iz/(L^2*(1+phiy));
cy =   6*E*Iy/(L^2*(1+phiz));
dz =  -6*E*Iz/(L^2*(1+phiy));
dy =  -6*E*Iy/(L^2*(1+phiz));

ez = (4+phiy)*E*Iz/(L*(1+phiy));
ey = (4+phiz)*E*Iy/(L*(1+phiz));
fz = (2-phiy)*E*Iz/(L*(1+phiy));
fy = (2-phiz)*E*Iy/(L*(1+phiz));

% Rotational inertia
ry = sqrt(Iy/A);
rz = sqrt(Iz/A);

A_z = (13/35+7/10*phiy+1/3*phiy^2+6/5*(rz/L)^2)/(1+phiy)^2;
A_y = (13/35+7/10*phiz+1/3*phiz^2+6/5*(ry/L)^2)/(1+phiz)^2;
B_z = (9/70+3/10*phiy+1/6*phiy^2-6/5*(rz/L)^2)/(1+phiy)^2;
B_y = (9/70+3/10*phiz+1/6*phiz^2-6/5*(ry/L)^2)/(1+phiz)^2;
C_z = (11/210+11/120*phiy+1/24*phiy^2+(1/10-1/2*phiy)*(rz/L)^2)*L/...
    (1+phiy)^2;
C_y = (11/210+11/120*phiz+1/24*phiz^2+(1/10-1/2*phiz)*(ry/L)^2)*L/...
    (1+phiz)^2;
D_z = (13/420+3/40*phiy+1/24*phiy^2-(1/10-1/2*phiy)*(rz/L)^2)*L/(1+phiy)^2;
D_y = (13/420+3/40*phiz+1/24*phiz^2-(1/10-1/2*phiz)*(ry/L)^2)*L/(1+phiz)^2;
E_z = (1/105+1/60*phiy+1/120*phiy^2+(2/15+1/6*phiy+1/3*phiy^2)*(rz/L)^2)...
    *L^2/(1+phiy)^2;
E_y = (1/105+1/60*phiz+1/120*phiz^2+(2/15+1/6*phiz+1/3*phiz^2)*(ry/L)^2)...
    *L^2/(1+phiz)^2;
F_z = -1*(1/140+1/60*phiy+1/120*phiy^2+(1/30+1/6*phiy-1/6*phiy^2)*...
    (rz/L)^2)*L^2/(1+phiy)^2;
F_y = -1*(1/140+1/60*phiz+1/120*phiz^2+(1/30+1/6*phiz-1/6*phiz^2)*...
    (ry/L)^2)*L^2/(1+phiz)^2;

Ko= [...
  A*E/L  0     0     0     0     0  -A*E/L   0      0     0     0     0;
   0     az    0     0     0     cz    0     bz     0     0     0     cz;
   0     0     ay    0     dy    0     0     0      by    0     dy    0;
   0     0     0   G*J/L   0     0     0     0      0  -G*J/L   0     0;
   0     0     dy    0     ey    0     0     0      cy    0     fy    0;
   0     cz    0     0     0     ez    0     dz     0     0     0     fz;
 -A*E/L  0     0     0     0     0   A*E/L   0      0     0     0     0;
   0     bz    0     0     0     dz    0     az     0     0     0     -cz;
   0     0     by    0     cy    0     0     0      ay    0    -dy    0;
   0     0     0  -G*J/L   0     0     0     0      0   G*J/L   0     0;
   0     0     dy    0     fy    0     0     0     -dy    0     ey    0;
   0     cz    0     0     0     fz    0    -cz     0     0     0     ez];

Me=rho*A*L*[...
   1/3   0     0     0     0     0    1/6    0      0     0     0     0;
   0    A_z    0     0     0    C_z    0    B_z     0     0     0     -D_z;
   0     0    A_y    0   -C_y    0     0     0     B_y    0    D_y    0;
   0     0     0  J/(3*A)  0     0     0     0      0  J/(6*A)  0     0;
   0     0   -C_y    0    E_y    0     0     0    -D_y    0    F_y    0;
   0    C_z    0     0     0    E_z    0    D_z     0     0     0     F_z;
   1/6   0     0     0     0     0    1/3    0      0     0     0     0;
   0    B_z    0     0     0    D_z    0    A_z     0     0     0     -C_z;
   0     0    B_y    0   -D_y    0     0     0     A_y    0    C_y    0;
   0     0     0  J/(6*A)  0     0     0     0      0  J/(3*A)  0     0;
   0     0    D_y    0    F_y    0     0     0     C_y    0    E_y    0;
   0   -D_z    0     0     0    F_z    0   -C_z     0     0     0     E_z];

% Soil stiffness
kx=0;
ky=1;
kz=1;

kox=0;
koy=0;
koz=0;
         
Kos =[...
   kx    0     0     0     0     0     kx    0      0     0     0     0;
   0     ky    0     0     0     koz   0     ky     0     0     0     koz;
   0     0     kz    0     koy   0     0     0      kz    0     koy   0;
   0     0     0     kox   0     0     0     0      0     kox   0     0;
   0     0     koy   0     koy   0     0     0      kz    0     koy   0;
   0     koz   0     0     0     koz   0     ky     0     0     0     koz;
   kx    0     0     0     0     0     kx    0      0     0     0     0;
   0     ky    0     0     0     ky    0     ky     0     0     0     koz;
   0     0     kz    0     kz    0     0     0      kz    0     koy   0;
   0     0     0     kox   0     0     0     0      0     kox   0     0;
   0     0     koy   0     koy   0     0     0      koy   0     koy   0;
   0     koz   0     0     0     koz   0     koz    0     0     0     koz];

% Rotor mass
Mass_Rotor=110000+240000;
Mrot=Mass_Rotor*[...
   1/3   0     0     0     0     0    1/6    0      0     0     0     0;
   0    A_z    0     0     0    C_z    0    B_z     0     0     0     -D_z;
   0     0    A_y    0   -C_y    0     0     0     B_y    0    D_y    0;
   0     0     0  J/(3*A)  0     0     0     0      0  J/(6*A)  0     0;
   0     0   -C_y    0    E_y    0     0     0    -D_y    0    F_y    0;
   0    C_z    0     0     0    E_z    0    D_z     0     0     0     F_z;
   1/6   0     0     0     0     0    1/3    0      0     0     0     0;
   0    B_z    0     0     0    D_z    0    A_z     0     0     0     -C_z;
   0     0    B_y    0   -D_y    0     0     0     A_y    0    C_y    0;
   0     0     0  J/(6*A)  0     0     0     0      0  J/(3*A)  0     0;
   0     0    D_y    0    F_y    0     0     0     C_y    0    E_y    0;
   0   -D_z    0     0     0    F_z    0   -C_z     0     0     0     E_z];

% Stiffness and Mass matrix
K = Ko;
M = Me;
Ks= Kos;

% Damping Matrix

switch Damping
    
case 'DStr'

switch ProbAnalysis
    
    case {'Area','Soil'}

        switch WindSpeed
            case '8 m/s'
                aerodynamicDamping = 0.0349;
            case '14 m/s'
                aerodynamicDamping = 0.0573;
            case '18 m/s'
                aerodynamicDamping = 0.0641;
        end

        structuralDamping = 0.01;
        alp = 0;
        bet = structuralDamping+aerodynamicDamping;
        C = alp*M+bet*K;
        
    case {'Aerodynamic Damping','Combined'}
        
        structuralDamping = 0.01;
        aerodynamicDamping = PDAeroDy;
        alp = 0;
        bet = structuralDamping+aerodynamicDamping;
        C = alp*M+bet*K;

end

case 'DTop'
        
        structuralDamping = 0.01;
        alp = 0;
        bet = structuralDamping;
        C = alp*M+bet*K;
        
end