function [rf] = inrain_main(signal)

% =====================================================================
% FUNCTION - In-house rainflow counting computation
% =====================================================================
% written by Daniel Zwick, 07/2010
% updated                  11/2013



                          
    % search for local extrema in the time series
        tp = inrain_extrem(signal);
        

        
    % first round of rainflow counting
        [cycle_count, residue1] = inrain_counting(tp);

        % The technique adopted is to add the residue to itself and apply the
        % previous rainflow technique to the sequence composed of two residues.
        % Some care has to be taken in joining the two residues, depending on
        % their initial and final relative values and slope.
        
        % initialize double residual
            combc       = 0;
            residue1_2x = residue1;
            lr1         = length(residue1(:,1));
            
        % combination criteria
            if ((residue1(end,2) < residue1(1,2)) && (residue1(1,2) < residue1(2,2))) || ((residue1(end,2) > residue1(1,2)) && (residue1(1,2) > residue1(2,2)))
                combc = 1;
            elseif (((residue1(end-1,2) > residue1(end,2)) && (residue1(end,2) > residue1(1,2))) || ((residue1(end-1,2) < residue1(end,2)) && (residue1(end,2) < residue1(1,2))))
                combc = 2;
            end
            
        % copy elements from original representation to double representation
            if (combc == 1)
                for i=1:lr1-1
                    residue1_2x(i+lr1,1) = residue1(i+1,1) + residue1(end,1);
                    residue1_2x(i+lr1,2) = residue1(i+1,2);
                end
            elseif (combc == 2)
                for i=1:lr1
                    residue1_2x(i+lr1-1,1) = residue1(i,1) + residue1(end,1);
                    residue1_2x(i+lr1-1,2) = residue1(i,2);
                end
            else
                for i=1:lr1
                    residue1_2x(i+lr1,1) = residue1(i,1) + residue1(end,1);
                    residue1_2x(i+lr1,2) = residue1(i,2);
                end        
            end 

            

    % apply rainflow counting again
        [cycle, residue_loop] = inrain_counting(residue1_2x);
        for m=1:length(cycle(:,1))
            cycle_count(m,2) = cycle(m,1);
        end

        

    % apply rainflow counting until no more cycles can be extracted
        i = 2;
        while cycle_count(1,i) > 0
            [cycle, residue_loop] = inrain_counting(residue_loop);
            for m=1:length(cycle(:,1))
                cycle_count(m,i+1) = cycle(m,1);
            end
            i = i + 1;
        end

 
    
    % prepare output variable - rf(1,:) Cycles amplitude
        % reshape cycle_count
            rf = reshape(cycle_count,1,length(cycle_count(:,1))*length(cycle_count(1,:)));
        % remove zero elements
            rf(rf==0) = [];
    
            
        
end   % of function